##  Overview
By integrating with Microsoft Entra ID, SAP LeanIX supports the automatic discovery of AI agents registered in Microsoft Entra ID through Microsoft’s Entra Agent ID framework. This framework introduces a dedicated application type for AI agents and gives you a centralized way to identify and track them across your environment.
